@@ -23,7 +23,7 @@ from eigeningenuity.events import get_eventlog
 from eigeningenuity.assetmodel import get_assetmodel
 from eigeningenuity.smartdash import get_smartdash
 from eigeningenuity.sql import get_sql
-from eigeningenuity.settings import set_azure_client_id, set_azure_tenant_id, disable_azure_auth, disable_auth_token_cache, clear_auth_token_cache, set_api_token
+from eigeningenuity.settings import set_azure_tenant_id, set_azure_client_id, set_azure_client_secret, disable_azure_auth, disable_auth_token_cache, clear_auth_token_cache, set_api_token, set_auth_scope
 
-__all__ = ["get_historian", "get_historian_multi", "get_assetmodel", "get_elastic", "get_sql", "get_eventlog", "get_smartdash", "list_historians", "EigenServer", "set_azure_client_id", "set_azure_tenant_id", "disable_azure_auth", "disable_auth_token_cache", "clear_auth_token_cache", "set_api_token"]
+__all__ = ["get_historian", "get_historian_multi", "get_assetmodel", "get_elastic", "get_sql", "get_eventlog", "get_smartdash", "list_historians", "EigenServer", "set_azure_tenant_id", "set_azure_client_id", "set_azure_client_secret", "disable_azure_auth", "disable_auth_token_cache", "clear_auth_token_cache", "set_api_token", "set_auth_scope"]
 __version__ = pkg_resources.require("python-eigen-ingenuity")[0].version
